From f95c150da2d608b300549b0b1f2a7d89f2881ebe Mon Sep 17 00:00:00 2001
From: "epugh@opensourceconnections.com" <>
Date: Fri, 12 Feb 2021 10:11:09 -0500
Subject: [PATCH] common typo for defined fixed
---
.../conf/solrconfig-cache-enable-disable.xml | 15 ++++++---------
.../conf/solrconfig-memory-circuitbreaker.xml | 8 ++++----
.../solr/core/DirectoryFactoriesTest.java | 4 ++--
.../test/org/apache/solr/core/TestConfig.java | 18 +++++++++---------
solr/solr-ref-guide/src/_layouts/default.html | 2 +-
solr/solr-ref-guide/src/_layouts/home.html | 2 +-
6 files changed, 23 insertions(+), 26 deletions(-)
diff --git a/solr/core/src/test-files/solr/collection1/conf/solrconfig-cache-enable-disable.xml b/solr/core/src/test-files/solr/collection1/conf/solrconfig-cache-enable-disable.xml
index 29e1799d5d9..d51f8050c56 100644
--- a/solr/core/src/test-files/solr/collection1/conf/solrconfig-cache-enable-disable.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/solrconfig-cache-enable-disable.xml
@@ -24,7 +24,7 @@
-
+
true
@@ -85,6 +85,3 @@
-
-
-
diff --git a/solr/core/src/test-files/solr/collection1/conf/solrconfig-memory-circuitbreaker.xml b/solr/core/src/test-files/solr/collection1/conf/solrconfig-memory-circuitbreaker.xml
index 699a7bd77e4..6ab9f893022 100644
--- a/solr/core/src/test-files/solr/collection1/conf/solrconfig-memory-circuitbreaker.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/solrconfig-memory-circuitbreaker.xml
@@ -54,12 +54,12 @@
autowarmCount="0"/>
diff --git a/solr/core/src/test/org/apache/solr/core/DirectoryFactoriesTest.java b/solr/core/src/test/org/apache/solr/core/DirectoryFactoriesTest.java
index 4748a6f73fa..c033e736b4a 100644
--- a/solr/core/src/test/org/apache/solr/core/DirectoryFactoriesTest.java
+++ b/solr/core/src/test/org/apache/solr/core/DirectoryFactoriesTest.java
@@ -75,14 +75,14 @@ public class DirectoryFactoriesTest extends SolrTestCaseJ4 {
file.writeInt(42);
// TODO: even StandardDirectoryFactory & NRTCachingDirectoryFactory can't agree on this...
- // ... should we consider this explicitly undefinied?
+ // ... should we consider this explicitly undefined?
// ... or should *all* Caching DirFactories consult the cache as well as the disk itself?
// assertFalse(path + " should still not exist until file is closed", dirFac.exists(path));
} // implicitly close file...
// TODO: even StandardDirectoryFactory & NRTCachingDirectoryFactory can't agree on this...
- // ... should we consider this explicitly undefinied?
+ // ... should we consider this explicitly undefined?
// ... or should *all* Caching DirFactories consult the cache as well as the disk itself?
// assertTrue(path + " should exist once file is closed", dirFac.exists(path));
diff --git a/solr/solr-ref-guide/src/_layouts/default.html b/solr/solr-ref-guide/src/_layouts/default.html
index 5b929bc2e0e..75b66b2fe46 100755
--- a/solr/solr-ref-guide/src/_layouts/default.html
+++ b/solr/solr-ref-guide/src/_layouts/default.html
@@ -1,5 +1,5 @@
-{% comment %}NOTE: page_id is also definied in page.html{% endcomment %}
+{% comment %}NOTE: page_id is also defined in page.html{% endcomment %}
{% assign page_id = page.url | split: '/' | last | remove: '.html' %}
{% include head.html %}
diff --git a/solr/solr-ref-guide/src/_layouts/home.html b/solr/solr-ref-guide/src/_layouts/home.html
index e5b7119c35d..c1d9cb60a10 100644
--- a/solr/solr-ref-guide/src/_layouts/home.html
+++ b/solr/solr-ref-guide/src/_layouts/home.html
@@ -7,7 +7,7 @@ layout: default
Its main difference is that it uses a different class for the content
container in order to have freedom to customize it as needed. -->
-{% comment %}NOTE: page_id is also definied in default.html{% endcomment %}
+{% comment %}NOTE: page_id is also defined in default.html{% endcomment %}
{% assign page_id = page.url | split: '/' | last | remove: '.html' %}
diff --git a/solr/core/src/test/org/apache/solr/core/TestConfig.java b/solr/core/src/test/org/apache/solr/core/TestConfig.java
index a1404e14489..ccf31144b36 100644
--- a/solr/core/src/test/org/apache/solr/core/TestConfig.java
+++ b/solr/core/src/test/org/apache/solr/core/TestConfig.java
@@ -124,8 +124,8 @@ public class TestConfig extends SolrTestCaseJ4 {
System.setProperty("filterCache.enabled", "true");
System.setProperty("queryResultCache.enabled", "true");
System.setProperty("documentCache.enabled", "true");
- System.setProperty("user_definied_cache_XXX.enabled","true");
- // user_definied_cache_ZZZ.enabled defaults to false in config
+ System.setProperty("user_defined_cache_XXX.enabled","true");
+ // user_defined_cache_ZZZ.enabled defaults to false in config
sc = new SolrConfig(TEST_PATH().resolve("collection1"), "solrconfig-cache-enable-disable.xml");
assertNotNull(sc.filterCacheConfig);
@@ -134,14 +134,14 @@ public class TestConfig extends SolrTestCaseJ4 {
//
assertNotNull(sc.userCacheConfigs);
assertEquals(1, sc.userCacheConfigs.size());
- assertNotNull(sc.userCacheConfigs.get("user_definied_cache_XXX"));
+ assertNotNull(sc.userCacheConfigs.get("user_defined_cache_XXX"));
// disable all the core caches (and enable both user caches) via system properties and verify
System.setProperty("filterCache.enabled", "false");
System.setProperty("queryResultCache.enabled", "false");
System.setProperty("documentCache.enabled", "false");
- System.setProperty("user_definied_cache_XXX.enabled","true");
- System.setProperty("user_definied_cache_ZZZ.enabled","true");
+ System.setProperty("user_defined_cache_XXX.enabled","true");
+ System.setProperty("user_defined_cache_ZZZ.enabled","true");
sc = new SolrConfig(TEST_PATH().resolve("collection1"), "solrconfig-cache-enable-disable.xml");
assertNull(sc.filterCacheConfig);
@@ -150,11 +150,11 @@ public class TestConfig extends SolrTestCaseJ4 {
//
assertNotNull(sc.userCacheConfigs);
assertEquals(2, sc.userCacheConfigs.size());
- assertNotNull(sc.userCacheConfigs.get("user_definied_cache_XXX"));
- assertNotNull(sc.userCacheConfigs.get("user_definied_cache_ZZZ"));
+ assertNotNull(sc.userCacheConfigs.get("user_defined_cache_XXX"));
+ assertNotNull(sc.userCacheConfigs.get("user_defined_cache_ZZZ"));
- System.clearProperty("user_definied_cache_XXX.enabled");
- System.clearProperty("user_definied_cache_ZZZ.enabled");
+ System.clearProperty("user_defined_cache_XXX.enabled");
+ System.clearProperty("user_defined_cache_ZZZ.enabled");
System.clearProperty("filterCache.enabled");
System.clearProperty("queryResultCache.enabled");
System.clearProperty("documentCache.enabled");